@@ -24,8 +24,8 @@ class QLogValue3DAxisFormatterPrivate : public QValue3DAxisFormatterPrivate
     Q_DECLARE_PUBLIC(QLogValue3DAxisFormatter)
 
 public:
-    QLogValue3DAxisFormatterPrivate(QLogValue3DAxisFormatter *q);
-    virtual ~QLogValue3DAxisFormatterPrivate();
+    QLogValue3DAxisFormatterPrivate();
+    ~QLogValue3DAxisFormatterPrivate() override;
 
     void recalculate();
     void populateCopy(QValue3DAxisFormatter &copy) const;
